"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Registry = exports.DomainSchema = void 0;
const avsc_1 = __importDefault(require("avsc"));
const confluent_schema_registry_1 = require("@kafkajs/confluent-schema-registry");
const cm_libs_context_aware_error_1 = require("cm-libs-context-aware-error");
class DomainSchema {
    constructor(schema, disableSchemaRegistry = false) {
        if ('string' !== typeof schema) {
            schema = JSON.stringify(schema);
        }
        this.schemaValue = schema;
        if (disableSchemaRegistry && schema) {
            this.schema = avsc_1.default.Type.forSchema(JSON.parse(schema));
        }
    }
    async encode(value) {
        try {
            if (this.schema) {
                return this.schema.toBuffer(value);
            }
            if (undefined === this.registryId) {
                if (!this.schemaValue) {
                    return Buffer.alloc(0);
                }
                const { id } = await Registry.instance.register({
                    schema: this.schemaValue,
                    type: confluent_schema_registry_1.SchemaType.AVRO
                });
                this._registryId = id;
            }
            return await Registry.instance.encode(this.registryId, value);
        }
        catch (error) {
            (0, cm_libs_context_aware_error_1.throwError)(cm_libs_context_aware_error_1.errors.INVALID_MESSAGE, `Encode event failed: ${error.message}`, {
                registryId: this.registryId,
                error
            });
        }
    }
    async decode(value) {
        try {
            if (this.schema) {
                return this.schema.fromBuffer(value);
            }
            const ret = await Registry.instance.decode(value);
            return ret;
        }
        catch (error) {
            (0, cm_libs_context_aware_error_1.throwError)(cm_libs_context_aware_error_1.errors.INVALID_MESSAGE, `Decode event failed: ${error.message}`, {
                registryId: this.registryId,
                error
            });
        }
    }
    get registryId() {
        return this._registryId;
    }
}
exports.DomainSchema = DomainSchema;
class Registry {
    constructor(url, overrides) {
        this.registry = new confluent_schema_registry_1.SchemaRegistry({ host: url, ...overrides });
    }
    static init(url, overrides) {
        this.self = new Registry(url, overrides);
    }
    static get instance() {
        return this.self?.registry || (0, cm_libs_context_aware_error_1.throwError)(cm_libs_context_aware_error_1.errors.NOT_INITIALIZED, 'Registry initialization is required');
    }
}
exports.Registry = Registry;
//# sourceMappingURL=domain-schema.js.map