"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.authBasicTokenMiddleware = void 0;
const joi_1 = __importDefault(require("joi"));
const cm_libs_context_aware_error_1 = require("cm-libs-context-aware-error");
const type_1 = require("../type");
const auth_1 = require("../auth");
const http_auth_1 = require("./http-auth");
function authBasicTokenMiddleware(req, res, next) {
    const token = req.get('authorization');
    if (token && token.startsWith('Basic ')) {
        const auth = Buffer.from(token.replace('Basic ', ''), 'base64').toString('utf8');
        const loginInfo = auth.split(':');
        if (2 === loginInfo.length) {
            const { error, value } = joi_1.default.object()
                .keys({
                orgId: type_1._id,
                appDomain: type_1._appDomain,
                productId: type_1._id
            })
                .with('orgId', ['appDomain', 'productId'])
                .validate({
                orgId: req.get('x-org-id'),
                appDomain: req.get('x-app-domain'),
                productId: req.get('x-product-id')
            });
            if (error) {
                return next((0, cm_libs_context_aware_error_1.createError)(cm_libs_context_aware_error_1.errors.INVALID_REQUEST, error.message, {
                    function: 'authBasicTokenMiddleware',
                    details: error.details,
                    text: { input: error.details?.[0]?.context?.peers || error.details?.[0]?.context?.key }
                }));
            }
            const ability = (0, auth_1.generateAbility)();
            const authToken = (0, http_auth_1.getAuthToken)(req) || { type: null, info: { token: null, ability } };
            authToken.type = auth_1.AuthTokenType.Basic;
            authToken.info.token = token;
            authToken.info.ability = ability;
            authToken.info.authMetadata = {
                basic: {
                    username: loginInfo[0],
                    password: loginInfo[1],
                    orgId: value.orgId,
                    appDomain: value.appDomain,
                    productId: value.productId
                }
            };
            (0, http_auth_1.setAuthToken)(req, authToken);
        }
    }
    return next();
}
exports.authBasicTokenMiddleware = authBasicTokenMiddleware;
//# sourceMappingURL=http-auth-basic.js.map