"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.callRest = exports.callGraphQl = exports.setIntercallServiceToken = void 0;
const graphql_1 = require("graphql");
const axios_1 = __importDefault(require("axios"));
const cm_libs_context_aware_error_1 = require("cm-libs-context-aware-error");
const cm_libs_context_aware_logger_1 = require("cm-libs-context-aware-logger");
const cm_libs_utils_1 = require("cm-libs-utils");
let serviceToken;
function setIntercallServiceToken(token) {
    serviceToken = token;
}
exports.setIntercallServiceToken = setIntercallServiceToken;
async function callGraphQl(url, query, fn, headers, config) {
    try {
        if (headers && serviceToken && !headers?.authorization) {
            // Inject service token if configured
            headers.authorization = 'Bearer ' + serviceToken;
        }
        (0, cm_libs_context_aware_logger_1.log)(cm_libs_context_aware_logger_1.Level.DEBUG, () => `callingGraphQl ${url} - ${fn}`);
        if ('string' !== typeof query) {
            query = (0, graphql_1.print)(query);
        }
        const reqConfig = defaultConfig({ headers, ...config });
        const { data: result } = await axios_1.default.post(url, { query }, reqConfig);
        const data = result?.data?.[fn];
        (0, cm_libs_context_aware_logger_1.log)(cm_libs_context_aware_logger_1.Level.DETAIL, () => `calledGraphQl ${url} - ${fn}`);
        if (!result || result.errors) {
            const error = result?.errors[0];
            if (error) {
                (0, cm_libs_context_aware_error_1.throwFromError)(error, error?.extensions?.code || cm_libs_context_aware_error_1.errors.INTERCALL_ERROR, { url, query, fn, error }, false);
            }
            (0, cm_libs_context_aware_error_1.throwError)(cm_libs_context_aware_error_1.errors.INTERCALL_ERROR, 'callGraphQl ERROR', { url, query, fn }, false);
        }
        return data;
    }
    catch (error) {
        (0, cm_libs_context_aware_error_1.throwFromError)(error, cm_libs_context_aware_error_1.errors.INTERCALL_ERROR, { url, query, fn });
    }
}
exports.callGraphQl = callGraphQl;
async function callRest(url, method, params, headers, config) {
    try {
        if (headers && serviceToken && !headers?.authorization) {
            // Inject service token if configured
            headers.authorization = 'Bearer ' + serviceToken;
        }
        (0, cm_libs_context_aware_logger_1.log)(cm_libs_context_aware_logger_1.Level.DEBUG, () => `callingRest ${method} ${url}`);
        const reqConfig = defaultConfig({ url, method, headers, data: params, ...config });
        const { data: result } = await (0, axios_1.default)(reqConfig);
        const data = result?.data;
        (0, cm_libs_context_aware_logger_1.log)(cm_libs_context_aware_logger_1.Level.DETAIL, () => `calledRest ${method} ${url}`);
        if (!result || result.errors) {
            const error = result?.errors[0];
            if (error) {
                (0, cm_libs_context_aware_error_1.throwFromError)(error, error?.extensions?.code || cm_libs_context_aware_error_1.errors.INTERCALL_ERROR, { url, data: params, method, error }, false);
            }
            (0, cm_libs_context_aware_error_1.throwError)(cm_libs_context_aware_error_1.errors.INTERCALL_ERROR, 'callRest ERROR', { url, data: params, method }, false);
        }
        return data;
    }
    catch (error) {
        (0, cm_libs_context_aware_error_1.throwFromError)(error, cm_libs_context_aware_error_1.errors.INTERCALL_ERROR, { url, data: params, method });
    }
}
exports.callRest = callRest;
function defaultConfig(overrides) {
    const config = {
        maxBodyLength: Infinity,
        maxContentLength: Infinity,
        ...overrides
    };
    if ((0, cm_libs_utils_1.isUndefinedOrNullOrEmpty)(config.timeout)) {
        config.timeout = 120000; // Default timeout is 120 seconds
    }
    return config;
}
//# sourceMappingURL=intercall.js.map