import Joi from 'joi';
import { AccessInfo } from '../auth';
export declare enum RecordStatus {
    ACTIVE = "ACTIVE",
    INACTIVE = "INACTIVE"
}
export declare type BaseModelErrorHandler = (error: TypeError, params: BaseModelMiddlewareParams, accessInfo: AccessInfo) => never;
export declare type BaseModelQueryHandler<T> = () => Promise<T>;
export declare const OmitCreateInput: {
    createdBy: number;
    createdByName: string;
    updatedAt: any;
};
export declare const OmitUpdateInput: {
    updatedBy: number;
    updatedByName: string;
};
export declare type BaseModelMiddlewareParams = {
    model?: string;
    action: string;
    args: any;
    dataPath: string[];
    runInTransaction: boolean;
};
export declare type BaseModelBatchPayload = {
    count: number;
};
export declare type BaseModelSchemas = {
    schemaCreateInput?: Joi.ObjectSchema;
    schemaUpdateInput?: Joi.ObjectSchema;
};
export interface BaseModelQueryContext {
    schemas: BaseModelSchemas;
    accessInfo: AccessInfo;
}
export declare class BaseModelMiddleware<PrismaClient> {
    readonly client: PrismaClient;
    private errorHandler;
    private asyncLocalStorage;
    constructor(client: PrismaClient, errorHandler?: BaseModelErrorHandler);
    run<T>(context: BaseModelQueryContext, promise: BaseModelQueryHandler<T>): Promise<T>;
    private process;
    private packCreateArgs;
    private packUpdateArgs;
    private packUpsertArgs;
}
